FlutterMobileProtect class

MobileProtect singleton class

Constructors

FlutterMobileProtect()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

init Future<void>
Manually initialize MobileProtect
no setter

Static Methods

initializeAndroidSdkWithConfiguration(AndroidMobileProtectConfiguration configuration) → void
Initialize Android SDK with configuration
onDidCompleteAppStartupCallback(Future<void> callback(String)) → dynamic
onEventsCallback(Future<void> callback(String)) → dynamic
onProtectionCallback(Future<void> callback(String)) → dynamic
setUserIdentifier(String userIdentifier) → void
Set user identifier