init property

Future<void> get init

Manually initialize MobileProtect

Calling this method directly is not required as MobileProtect will be initialized automatically within the app's life-cycle on Android and iOS

Implementation

static Future<void> get init async {
  print(
      "Calling init is no longer required to initialize Mobile Protect, consider removing the call.");
  await _channel.invokeMethod('init');
}