RuntimeObfuscationItem class

Inheritance

Constructors

RuntimeObfuscationItem(ConfigKey configName, bool isEnabled, List<String>? exceptionList, Map<String, List<String>> obfuscationScope)

Properties

configName ConfigKey
finalinherited
exceptionList List<String>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
finalinherited
obfuscationScope Map<String, List<String>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited