ConfigKey enum
Values
- pasteboard → const ConfigKey
- camera → const ConfigKey
- dataAtRestCheck → const ConfigKey
- debuggerDetection → const ConfigKey
- deviceIdentifiers → const ConfigKey
- deviceLocation → const ConfigKey
- exifLocation → const ConfigKey
- rootDetection → const ConfigKey
- tapJackingProtection → const ConfigKey
- screenCastingProtection → const ConfigKey
- verifyApps → const ConfigKey
- photoAccess → const ConfigKey
- videoAccess → const ConfigKey
- downloadAccess → const ConfigKey
- calendarAccess → const ConfigKey
- contacts → const ConfigKey
- webviews → const ConfigKey
- tlsProviderSecurity → const ConfigKey
- tamperDetection → const ConfigKey
- cheatingDetection → const ConfigKey
- healthAccess → const ConfigKey
- microphoneAccess → const ConfigKey
- coverageMetrics → const ConfigKey
- activityCoverageMetrics → const ConfigKey
- emulatorProtection → const ConfigKey
- virtualPrivateNetwork → const ConfigKey
- thirdPartyKeyboard → const ConfigKey
- jailbreakDetection → const ConfigKey
- spywareDetection → const ConfigKey
- dynamicObfuscation → const ConfigKey
- viewCoverageMetrics → const ConfigKey
- simulatorDetection → const ConfigKey
- locationChecks → const ConfigKey
- iPChecks → const ConfigKey
- wifiChecks → const ConfigKey
- outdatedOSCheck → const ConfigKey
- phoneNumberCheck → const ConfigKey
- batteryCheck → const ConfigKey
- appClonerCheck → const ConfigKey
- sDKChecks → const ConfigKey
- hardwareSpooferChecks → const ConfigKey
- cellularChecks → const ConfigKey
- signatureChecks → const ConfigKey
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited