MobileProtectConfiguration class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAuthenticationToken(
String token) → void -
setConfig(
ConfigKey key, bool isEnabled, [List< String> ? exceptionList]) → void -
setIOSDebugLoggingEnabled(
bool enabled) → void -
setIOSResourceValidationDisabled(
bool disabled) → void -
setIOSSymbolicationDisabled(
bool disabled) → void -
toJson(
PlatformType platform) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited